@@ -512,8 +512,6 @@ impl<'h, I> Parser<'h, I> where I: Iterator<Item=Result<TokenMeta, LexerError>>
             
             ctx.pop_extend();
             
-            let op = op.map(|op| op.into());
-            
             let nonlocal = matches!(optional_token.map(|tok| tok.token), Some(Token::NonLocal));
             
             let assign = Box::new(Assignment { lhs, op, rhs, nonlocal });
@@ -585,7 +583,7 @@ impl<'h, I> Parser<'h, I> where I: Iterator<Item=Result<TokenMeta, LexerError>>
         let mut first_expr = Some(self.parse_binop_expr(ctx)?); // might be taken into tuple later
         
         // check for tuple constructor
-        let mut tuple_exprs = Vec::<ExprMeta>::new();
+        let mut tuple_exprs = Vec::new();
         loop {
             let next = self.peek()?;
             if !matches!(next.token, Token::Comma) {
@@ -603,6 +601,11 @@ impl<'h, I> Parser<'h, I> where I: Iterator<Item=Result<TokenMeta, LexerError>>
             
             ctx.set_end(&self.advance().unwrap()); // consume comma
             
+            let next = self.peek()?;
+            if matches!(next.token, Token::CloseParen) {
+                break;
+            }
+            
             ctx.push(ContextTag::ExprMeta);
             let next_expr = self.parse_binop_expr(ctx)?;
             let symbol = ctx.frame().as_debug_symbol().unwrap();
@@ -657,7 +660,7 @@ impl<'h, I> Parser<'h, I> where I: Iterator<Item=Result<TokenMeta, LexerError>>
             
             let rhs_expr = self.parse_binop_expr_levels(ctx, level - 1)?;
             
-            expr = Expr::BinaryOp(binary_op.into(), Box::new((expr, rhs_expr)));
+            expr = Expr::BinaryOp(binary_op, Box::new((expr, rhs_expr)));
         }
         
         if push_ctx {
@@ -681,7 +684,7 @@ impl<'h, I> Parser<'h, I> where I: Iterator<Item=Result<TokenMeta, LexerError>>
             let expr = self.parse_unary_expr(ctx)?;
             
             ctx.pop_extend();
-            return Ok(Expr::UnaryOp(unary_op.into(), Box::new(expr)));
+            return Ok(Expr::UnaryOp(unary_op, Box::new(expr)));
         }
         
         self.parse_primary_expr(ctx)
@@ -1308,6 +1311,10 @@ impl<'h, I> Parser<'h, I> where I: Iterator<Item=Result<TokenMeta, LexerError>>
                     return Err(ErrorKind::SyntaxError(message).into())
                 },
                 
+                Token::CloseParen => return Err("unmatched \")\"".into()),
+                Token::CloseSquare => return Err("unmatched \"]\"".into()),
+                Token::CloseBrace => return Err("unmatched \"}\"".into()),
+                
                 _ => { return Err("expected an expression here".into()) },
             };
             
