@@ -102,12 +102,6 @@ impl Closure {
     pub fn is_closed(&self) -> bool { matches!(self, Self::Closed(..)) }
 }
 
-unsafe impl GcTrace for Cell<Variant> {
-    fn trace(&self) {
-        self.get().trace()
-    }
-}
-
 
 #[derive(Debug, Clone)]
 pub struct Upvalue {
@@ -176,7 +170,7 @@ impl Callable for Gc<NativeFunction> {
 
 unsafe impl GcTrace for NativeFunction {
     fn trace(&self) {
-        Gc::mark_trace(&self.env);
+        self.env.mark_trace();
         
         if let Some(defaults) = self.defaults.as_ref() {
             defaults.trace()
