@@ -67,7 +67,6 @@ pub trait MetaObject {
     
     // formatting
     fn fmt_echo(&self) -> ExecResult<StringValue>;
-    fn fmt_str(&self) -> ExecResult<StringValue> { self.fmt_echo() }
     
     // primitive coercions
     fn as_bool(&self) -> ExecResult<bool> { Ok(true) }
@@ -169,13 +168,8 @@ impl Variant {
     pub fn fmt_echo(&self) -> ExecResult<StringValue> {
         self.as_meta().fmt_echo()
     }
-    
-    pub fn fmt_str(&self) -> ExecResult<StringValue> {
-        self.as_meta().fmt_str()
-    }
 }
 
-
 // Nil
 impl MetaObject for () {
     fn type_tag(&self) -> Type { Type::Nil }
@@ -276,7 +270,7 @@ impl<F> MetaObject for Gc<F> where F: GcTrace, Gc<F>: Callable {
     fn fmt_echo(&self) -> ExecResult<StringValue> {
         // TODO cache this in the signature struct
         let result = format!(
-            "<{} at {:#X}>", self.signature().display_short(), Gc::as_id(self)
+            "<{} at {:#X}>", self.signature().fmt_name(), Gc::as_id(self)
         );
         Ok(StringValue::new_uninterned(result))
     }
@@ -292,7 +286,6 @@ pub enum MethodTag {
     AsBits,
     AsInt,
     AsFloat,
-    ToString,
     Echo,
 }
 
@@ -314,7 +307,7 @@ impl MethodTag {
             Self::AsInt => "int",
             Self::AsFloat => "float",
             
-            Self::ToString => "tostring",
+            // misc
             Self::Echo => "echo",
         }
     }
